# NOWPreprocessor

Applies preprocessing to documents for encoding, indexing and searching as defined by app. If necessary,
    downloads files for that from cloud bucket.
    
Also, provides an endpoint to download data from S3 bucket without requiring credentials for that.